	IFND	LIBRARIES_CON_I
LIBRARIES_CON_I SET 1

;==================================================================
;===	Include for "con.library" by BReese
;==================================================================

	IFND	EXEC_LIBRARIES_I
	INCLUDE	'exec/libraries.i'
	ENDC
	IFND	INTUITION_INTUITION_I
	INCLUDE	'intuition/intuition.i'
	ENDC

CONNAME: MACRO				; Name of the Library
	DC.B	'con.library',0
	ENDM

CHARDEFSIZE	EQU (256+7)/8		; 256 ASCII Characters
IGNOREVALUE	EQU -1

;==================================================================
;===	ConBase
;==================================================================

      STRUCTURE	con_,0
	STRUCT	con_LibNode,LIB_SIZE	; Library Node
	APTR	con_SegList		; Segment List [from LoadSeg()]
	APTR	con_IntBase		; Intuition Base
	APTR	con_MathBase		; MathFFP Base
	LABEL	con_SIZEOF

;==================================================================
;===	ConHandle
;==================================================================

      STRUCTURE	cnh_,0
	APTR	cnh_CDBase		; Base of Console Device
	APTR	cnh_Window		; Our Intuition Window
	APTR	cnh_UserPort		; UserPort for Window
	APTR	cnh_Unit		; ConUnit
	APTR	cnh_WriteIO		; Our Write IO Port
	ULONG	cnh_Signal		; SignalSet [for Wait()]
	UWORD	cnh_ExLength		; Extra Space for String Formatting
	UWORD	cnh_CursorStatus	; Current Cursor Status [on/off]
	UBYTE	cnh_PadSpace		; Char for Leading Spaces in Numbers
	UBYTE	cnh_PadZero		; Char for Leading Zeros in Numbers
	UBYTE	cnh_PadGroup		; Char for Group Classifying
	UBYTE	cnh_PadString		; Char for Unused String Positions
	UBYTE	cnh_DecimalPoint	; Char for Decimal Point
	UBYTE	cnh_FloatE		; Char for Floating Point Exponent
	STRUCT	cnh_EchoTable,CHARDEFSIZE	; BitTable of Echo Chars
	STRUCT	cnh_UserNotes,8*4	; List of Pointers to UserNotes
	APTR	cnh_MsgHandler		; Pointer to a User Message Handler
	STRUCT	cnh_Reserved,4*4	; Reserved for future use
	LABEL	cnh_SIZEOF

;==================================================================
;===	ConInfo
;==================================================================

      STRUCTURE	cin_,0
	UWORD	cin_XPos		; Cursor X Position
	UWORD	cin_YPos		; Cursor Y Position
	UWORD	cin_XSize		; Chars per Line
	UWORD	cin_YSize		; Lines in Window
	UWORD	cin_Styles		; Text Styles
	UWORD	cin_FgCol		; Foreground Color
	UWORD	cin_BgCol		; Background Color
	STRUCT	cin_Reserved,4*4	; Reserved for future use
	LABEL	cin_SIZEOF

;==================================================================
;===	AcceptStructure
;==================================================================

      STRUCTURE	_acc,0
	UWORD	acc_XStart		; Start X Position
	UWORD	acc_YStart		; Start Y Position
	UWORD	acc_Styles		; Text Styles
	UWORD	acc_FgCol		; Foreground Color
	UWORD	acc_BgCol		; Background Color
	ULONG	acc_ExitFlags		; IDCMP Exit Flags
	ULONG	acc_Class		; Copy of im_Class
	UWORD	acc_Code		; Copy of im_Code
	UWORD	acc_Qualifier		; Copy of im_Qualifier
	APTR	acc_IAddress		; Copy of im_IAddress
	WORD	acc_MouseX		; Copy of im_MouseX
	WORD	acc_MouseY		; Copy of im_MouseY
	ULONG	acc_Seconds		; Copy of im_Seconds
	ULONG	acc_Micros		; Copy of im_Micros
	APTR	acc_IDCMPWindow		; Copy of im_IDCMPWindow
	UBYTE	acc_Char		; ASCII char
	UBYTE	acc_Pad001		; Nothing serious
	STRUCT	acc_ValidTable,CHARDEFSIZE	; BitTable of Valid Chars
	STRUCT	acc_ExitTable,CHARDEFSIZE	; BitTable of Exit Chars
	STRUCT	acc_Reserved,4*4	; Reserved for future use
	LABEL	acc_SIZEOF
;--- Extended AcceptString() Structure
	APTR	accs_InputBuffer	; Pointer to Input Buffer
	APTR	accs_WorkBuffer		; Pointer to Work Buffer
	UWORD	accs_MaxLength		; Maximum Length of Text [incl. NULL]
	UWORD	accs_FieldLen		; Length of Input Field [incl. NULL]
	UWORD	accs_Length		; Current Length of Text [excl. NULL]
	UWORD	accs_Position		; Current Position in Text
	UWORD	accs_DispPos		; First Displayed Position in Text
	STRUCT	accs_Reserved,4*4	; Reserved for future use
	LABEL	accs_SIZEOF


;==================================================================
;===	Codes for DefineChar()
;==================================================================

;=== Modes
DEFMODE_ALL	EQU 0
DEFMODE_NEW	EQU 1
DEFMODE_ADD	EQU 2
DEFMODE_REM	EQU 3
DEFMODE_GET	EQU 4

;=== Pre-defined Tables
DEFALL		EQU 0<<17
DEFNONE		EQU 1<<17
DEFALFANUM	EQU 2<<17
DEFALFA		EQU 3<<17
DEFNUMERIC	EQU 4<<17
DEFDECIMAL	EQU 5<<17
DEFHEX		EQU 6<<17
DEFOCTAL	EQU 7<<17
DEFBINARY	EQU 8<<17
DEFFLOAT	EQU 9<<17

;==================================================================
;===	Codes for Cursor()
;==================================================================

CURSOROFF	EQU 0
CURSORON	EQU 1

;==================================================================
;===	Codes for Accept() & AcceptString()
;==================================================================

;=== General Flags
ACCB_ERASE	EQU 31
ACCF_ERASE	EQU 1<<ACCB_ERASE

;=== Accept Flags
ACCB_RAWKEY	EQU 28
ACCF_RAWKEY	EQU 1<<ACCB_RAWKEY
ACCB_DUALKEY	EQU 27
ACCF_DUALKEY	EQU 1<<ACCB_DUALKEY
ACCB_UPKEY	EQU 26
ACCF_UPKEY	EQU 1<<ACCB_UPKEY
ACCB_ECHO	EQU 25
ACCF_ECHO	EQU 1<<ACCB_ECHO
ACCB_WAIT	EQU 24
ACCF_WAIT	EQU 1<<ACCB_WAIT

;=== AcceptString Flags
ACCB_JUSTIFIED	EQU 22
ACCF_JUSTIFIED	EQU 1<<ACCB_JUSTIFIED
ACCB_CONTINUE	EQU 21
ACCF_CONTINUE	EQU 1<<ACCB_CONTINUE
ACCB_OVERWRITE	EQU 20
ACCF_OVERWRITE	EQU 1<<ACCB_OVERWRITE
ACCB_LASTEXIT	EQU 19
ACCF_LASTEXIT	EQU 1<<ACCB_LASTEXIT
ACCB_FULLSTOP	EQU 18
ACCF_FULLSTOP	EQU 1<<ACCB_FULLSTOP
ACCB_NOAMIGA	EQU 17
ACCF_NOAMIGA	EQU 1<<ACCB_NOAMIGA
ACCB_NOSTDAMIGA	EQU 16
ACCF_NOSTDAMIGA	EQU 1<<ACCB_NOSTDAMIGA
ACCB_NOSCROLL	EQU 15
ACCF_NOSCROLL	EQU 1<<ACCB_NOSCROLL


;==================================================================
;===	Codes for SetGfx()
;==================================================================

SGFB_PLAIN	EQU 0
SGFF_PLAIN	EQU 1<<SGFB_PLAIN
SGFB_BOLD	EQU 1
SGFF_BOLD	EQU 1<<SGFB_BOLD
SGFB_ITALIC	EQU 2
SGFF_ITALIC	EQU 1<<SGFB_ITALIC
SGFB_UNDERLINED	EQU 3
SGFF_UNDERLINED	EQU 1<<SGFB_UNDERLINED


;==================================================================
;===	Codes for Convert()
;==================================================================

;=== Modes
CNV_DECIMAL	EQU 1
CNV_HEX		EQU 2
CNV_OCTAL	EQU 3
CNV_BINARY	EQU 4

;=== Attributes
CNV_SIGNED	EQU 1<<16
CNV_LEADSPACE	EQU 1<<17


;==================================================================
;===	Codes for Special Keys
;==================================================================

AKEY_NONE	EQU 0
AKEY_HELP	EQU 5
AKEY_BS		EQU 8
AKEY_TAB	EQU 9
AKEY_LF		EQU 10
AKEY_RETURN	EQU 13
AKEY_ARROWRG	EQU 17
AKEY_ARROWLF	EQU 18
AKEY_ARROWUP	EQU 19
AKEY_ARROWDN	EQU 20
AKEY_ESC	EQU 27
AKEY_DEL	EQU 127
AKEY_F1		EQU 129
AKEY_F2		EQU 130
AKEY_F3		EQU 131
AKEY_F4		EQU 132
AKEY_F5		EQU 133
AKEY_F6		EQU 134
AKEY_F7		EQU 135
AKEY_F8		EQU 136
AKEY_F9		EQU 137
AKEY_F10	EQU 138
AKEY_CSI	EQU 155
	ENDC
